@@ -152,8 +152,9 @@ static int pcu_tx_info_ind(struct gsm_bts *bts)
 		info_ind->flags |= PCU_IF_FLAG_SYSMO;
 
 	/* RAI */
-	info_ind->mcc = bts->network->country_code;
-	info_ind->mnc = bts->network->network_code;
+	info_ind->mcc = bts->network->plmn.mcc;
+	info_ind->mnc = bts->network->plmn.mnc;
+	info_ind->mnc_3_digits = bts->network->plmn.mnc_3_digits;
 	info_ind->lac = bts->location_area_code;
 	info_ind->rac = bts->gprs.rac;
 
@@ -483,7 +484,7 @@ static int pcu_sock_send(struct gsm_bts *bts, struct msgb *msg)
 		return -EIO;
 	}
 	msgb_enqueue(&state->upqueue, msg);
-	conn_bfd->when |= BSC_FD_WRITE;
+	conn_bfd->when |= OSMO_FD_WRITE;
 
 	return 0;
 }
@@ -506,7 +507,7 @@ static void pcu_sock_close(struct pcu_sock_state *state)
 	osmo_fd_unregister(bfd);
 
 	/* re-enable the generation of ACCEPT for new connections */
-	state->listen_bfd.when |= BSC_FD_READ;
+	state->listen_bfd.when |= OSMO_FD_READ;
 
 #if 0
 	/* remove si13, ... */
@@ -585,7 +586,7 @@ static int pcu_sock_write(struct osmo_fd *bfd)
 		msg = llist_entry(state->upqueue.next, struct msgb, list);
 		pcu_prim = (struct gsm_pcu_if *)msg->data;
 
-		bfd->when &= ~BSC_FD_WRITE;
+		bfd->when &= ~OSMO_FD_WRITE;
 
 		/* bug hunter 8-): maybe someone forgot msgb_put(...) ? */
 		if (!msgb_length(msg)) {
@@ -600,7 +601,7 @@ static int pcu_sock_write(struct osmo_fd *bfd)
 			goto close;
 		if (rc < 0) {
 			if (errno == EAGAIN) {
-				bfd->when |= BSC_FD_WRITE;
+				bfd->when |= OSMO_FD_WRITE;
 				break;
 			}
 			goto close;
@@ -624,12 +625,12 @@ static int pcu_sock_cb(struct osmo_fd *bfd, unsigned int flags)
 {
 	int rc = 0;
 
-	if (flags & BSC_FD_READ)
+	if (flags & OSMO_FD_READ)
 		rc = pcu_sock_read(bfd);
 	if (rc < 0)
 		return rc;
 
-	if (flags & BSC_FD_WRITE)
+	if (flags & OSMO_FD_WRITE)
 		rc = pcu_sock_write(bfd);
 
 	return rc;
@@ -655,13 +656,13 @@ static int pcu_sock_accept(struct osmo_fd *bfd, unsigned int flags)
 		LOGP(DPCU, LOGL_NOTICE, "PCU connects but we already have "
 			"another active connection ?!?\n");
 		/* We already have one PCU connected, this is all we support */
-		state->listen_bfd.when &= ~BSC_FD_READ;
+		state->listen_bfd.when &= ~OSMO_FD_READ;
 		close(rc);
 		return 0;
 	}
 
 	conn_bfd->fd = rc;
-	conn_bfd->when = BSC_FD_READ;
+	conn_bfd->when = OSMO_FD_READ;
 	conn_bfd->cb = pcu_sock_cb;
 	conn_bfd->data = state;
 
@@ -704,7 +705,7 @@ int pcu_sock_init(const char *path, struct gsm_bts *bts)
 		return -1;
 	}
 
-	bfd->when = BSC_FD_READ;
+	bfd->when = OSMO_FD_READ;
 	bfd->cb = pcu_sock_accept;
 	bfd->data = state;
 
