@@ -37,6 +37,7 @@
 #include <openbsc/abis_rsl.h>
 #include <openbsc/rest_octets.h>
 #include <openbsc/arfcn_range_encode.h>
+#include <openbsc/acc_ramp.h>
 
 /*
  * DCS1800 and PCS1900 have overlapping ARFCNs. We would need to set the
@@ -662,6 +663,8 @@ static int generate_si1(enum osmo_sysinfo_type t, struct gsm_bts *bts)
 	list_arfcn(si1->cell_channel_description, 0xce, "Serving cell:");
 
 	si1->rach_control = bts->si_common.rach_control;
+	if (acc_ramp_is_enabled(&bts->acc_ramp))
+		acc_ramp_apply(&si1->rach_control, &bts->acc_ramp);
 
 	/*
 	 * SI1 Rest Octets (10.5.2.32), contains NCH position and band
@@ -692,6 +695,8 @@ static int generate_si2(enum osmo_sysinfo_type t, struct gsm_bts *bts)
 
 	si2->ncc_permitted = bts->si_common.ncc_permitted;
 	si2->rach_control = bts->si_common.rach_control;
+	if (acc_ramp_is_enabled(&bts->acc_ramp))
+		acc_ramp_apply(&si2->rach_control, &bts->acc_ramp);
 
 	return sizeof(*si2);
 }
@@ -725,6 +730,8 @@ static int generate_si2bis(enum osmo_sysinfo_type t, struct gsm_bts *bts)
 		bts->si_valid &= ~(1 << SYSINFO_TYPE_2bis);
 
 	si2b->rach_control = bts->si_common.rach_control;
+	if (acc_ramp_is_enabled(&bts->acc_ramp))
+		acc_ramp_apply(&si2b->rach_control, &bts->acc_ramp);
 
 	return sizeof(*si2b);
 }
@@ -802,8 +809,8 @@ static struct gsm48_si_ro_info si_info = {
 	.power_offset = {
 		.present = 0,
 	},
-	.si2ter_indicator = 0,
-	.early_cm_ctrl = 1,
+	.si2ter_indicator = false,
+	.early_cm_ctrl = true,
 	.scheduling = {
 		.present = 0,
 	},
@@ -812,7 +819,8 @@ static struct gsm48_si_ro_info si_info = {
 		.ra_colour = 0,
 		.present = 1,
 	},
-	.si2quater_indicator = 0,
+	.early_cm_restrict_3g = false,
+	.si2quater_indicator = false,
 	.lsa_params = {
 		.present = 0,
 	},
@@ -833,31 +841,32 @@ static int generate_si3(enum osmo_sysinfo_type t, struct gsm_bts *bts)
 	si3->header.system_information = GSM48_MT_RR_SYSINFO_3;
 
 	si3->cell_identity = htons(bts->cell_identity);
-	gsm48_generate_lai(&si3->lai, bts->network->country_code,
-			   bts->network->network_code,
-			   bts->location_area_code);
+	gsm48_generate_lai2(&si3->lai, bts_lai(bts));
 	si3->control_channel_desc = bts->si_common.chan_desc;
 	si3->cell_options = bts->si_common.cell_options;
 	si3->cell_sel_par = bts->si_common.cell_sel_par;
 	si3->rach_control = bts->si_common.rach_control;
+	if (acc_ramp_is_enabled(&bts->acc_ramp))
+		acc_ramp_apply(&si3->rach_control, &bts->acc_ramp);
 
 	/* allow/disallow DTXu */
 	gsm48_set_dtx(&si3->cell_options, bts->dtxu, bts->dtxu, true);
 
 	if (GSM_BTS_HAS_SI(bts, SYSINFO_TYPE_2ter)) {
 		LOGP(DRR, LOGL_INFO, "SI 2ter is included.\n");
-		si_info.si2ter_indicator = 1;
+		si_info.si2ter_indicator = true;
 	} else {
-		si_info.si2ter_indicator = 0;
+		si_info.si2ter_indicator = false;
 	}
 	if (GSM_BTS_HAS_SI(bts, SYSINFO_TYPE_2quater)) {
 		LOGP(DRR, LOGL_INFO, "SI 2quater is included, based on %zu EARFCNs and %zu UARFCNs.\n",
 		     si2q_earfcn_count(&bts->si_common.si2quater_neigh_list), bts->si_common.uarfcn_length);
-		si_info.si2quater_indicator = 1;
+		si_info.si2quater_indicator = true;
 	} else {
-		si_info.si2quater_indicator = 0;
+		si_info.si2quater_indicator = false;
 	}
 	si_info.early_cm_ctrl = bts->early_classmark_allowed;
+	si_info.early_cm_restrict_3g = !bts->early_classmark_allowed_3g;
 
 	/* SI3 Rest Octets (10.5.2.34), containing
 		CBQ, CELL_RESELECT_OFFSET, TEMPORARY_OFFSET, PENALTY_TIME
@@ -884,11 +893,11 @@ static int generate_si4(enum osmo_sysinfo_type t, struct gsm_bts *bts)
 	si4->header.skip_indicator = 0;
 	si4->header.system_information = GSM48_MT_RR_SYSINFO_4;
 
-	gsm48_generate_lai(&si4->lai, bts->network->country_code,
-			   bts->network->network_code,
-			   bts->location_area_code);
+	gsm48_generate_lai2(&si4->lai, bts_lai(bts));
 	si4->cell_sel_par = bts->si_common.cell_sel_par;
 	si4->rach_control = bts->si_common.rach_control;
+	if (acc_ramp_is_enabled(&bts->acc_ramp))
+		acc_ramp_apply(&si4->rach_control, &bts->acc_ramp);
 
 	/* Optional: CBCH Channel Description + CBCH Mobile Allocation */
 	cbch_lchan = gsm_bts_get_cbch(bts);
@@ -931,7 +940,7 @@ static int generate_si5(enum osmo_sysinfo_type t, struct gsm_bts *bts)
 		break;
 	}
 
-	si5 = (struct gsm48_system_information_type_5 *) GSM_BTS_SI(bts, t);
+	si5 = (struct gsm48_system_information_type_5 *) output;
 
 	/* l2 pseudo length, not part of msg: 18 */
 	si5->rr_protocol_discriminator = GSM48_PDISC_RR;
@@ -967,7 +976,7 @@ static int generate_si5bis(enum osmo_sysinfo_type t, struct gsm_bts *bts)
 		break;
 	}
 
-	si5b = (struct gsm48_system_information_type_5bis *) GSM_BTS_SI(bts, t);
+	si5b = (struct gsm48_system_information_type_5bis *) output;
 
 	/* l2 pseudo length, not part of msg: 18 */
 	si5b->rr_protocol_discriminator = GSM48_PDISC_RR;
@@ -981,7 +990,7 @@ static int generate_si5bis(enum osmo_sysinfo_type t, struct gsm_bts *bts)
 	if (n) {
 		/* indicate in SI5 and SI5bis: there is an extension */
 		struct gsm48_system_information_type_5 *si5 =
-			(struct gsm48_system_information_type_5 *) GSM_BTS_SI(bts, SYSINFO_TYPE_5);
+			(struct gsm48_system_information_type_5 *) GSM_BTS_SI(bts, SYSINFO_TYPE_5)+1;
 		si5->bcch_frequency_list[0] |= 0x20;
 		si5b->bcch_frequency_list[0] |= 0x20;
 	} else
@@ -1011,7 +1020,7 @@ static int generate_si5ter(enum osmo_sysinfo_type t, struct gsm_bts *bts)
 		break;
 	}
 
-	si5t = (struct gsm48_system_information_type_5ter *) GSM_BTS_SI(bts, t);
+	si5t = (struct gsm48_system_information_type_5ter *) output;
 
 	/* l2 pseudo length, not part of msg: 18 */
 	si5t->rr_protocol_discriminator = GSM48_PDISC_RR;
@@ -1049,16 +1058,14 @@ static int generate_si6(enum osmo_sysinfo_type t, struct gsm_bts *bts)
 		break;
 	}
 
-	si6 = (struct gsm48_system_information_type_6 *) GSM_BTS_SI(bts, t);
+	si6 = (struct gsm48_system_information_type_6 *) output;
 
 	/* l2 pseudo length, not part of msg: 11 */
 	si6->rr_protocol_discriminator = GSM48_PDISC_RR;
 	si6->skip_indicator = 0;
 	si6->system_information = GSM48_MT_RR_SYSINFO_6;
 	si6->cell_identity = htons(bts->cell_identity);
-	gsm48_generate_lai(&si6->lai, bts->network->country_code,
-			   bts->network->network_code,
-			   bts->location_area_code);
+	gsm48_generate_lai2(&si6->lai, bts_lai(bts));
 	si6->cell_options = bts->si_common.cell_options;
 	si6->ncc_permitted = bts->si_common.ncc_permitted;
 	/* allow/disallow DTXu */
