@@ -49,11 +49,6 @@
 	memset(str, 0, sizeof(*str));			\
 	rc = smpp34_unpack(type, str, data, len)
 
-enum emse_bind {
-	ESME_BIND_RX = 0x01,
-	ESME_BIND_TX = 0x02,
-};
-
 const struct value_string smpp_status_strs[] = {
 	{ ESME_ROK,		"No Error" },
 	{ ESME_RINVMSGLEN,	"Message Length is invalid" },
@@ -148,6 +143,7 @@ struct osmo_smpp_acl *smpp_acl_alloc(struct smsc *smsc, const char *sys_id)
 
 	acl->smsc = smsc;
 	strcpy(acl->system_id, sys_id);
+	acl->alert_notifications = 1;
 	INIT_LLIST_HEAD(&acl->route_list);
 
 	llist_add_tail(&acl->list, &smsc->acl_list);
@@ -919,7 +915,7 @@ static int link_accept_cb(struct smsc *smsc, int fd,
 	osmo_wqueue_init(&esme->wqueue, 10);
 	esme->wqueue.bfd.fd = fd;
 	esme->wqueue.bfd.data = esme;
-	esme->wqueue.bfd.when = BSC_FD_READ;
+	esme->wqueue.bfd.when = OSMO_FD_READ;
 
 	if (osmo_fd_register(&esme->wqueue.bfd) != 0) {
 		close(fd);
