@@ -164,7 +164,7 @@ DEFUN(cfg_smpp_sys_id, cfg_smpp_sys_id_cmd,
 DEFUN(cfg_smpp_policy, cfg_smpp_policy_cmd,
 	"policy (accept-all|closed)",
 	"Set the authentication policy of this SMSC\n"
-	"Accept all SMPP connections independeint of system ID / passwd\n"
+	"Accept all SMPP connections independent of system ID / password\n"
 	"Accept only SMPP connections from ESMEs explicitly configured")
 {
 	struct smsc *smsc = smsc_from_vty(vty);
@@ -499,6 +499,28 @@ DEFUN(cfg_esme_no_dcs_transp, cfg_esme_no_dcs_transp_cmd,
 	return CMD_SUCCESS;
 }
 
+DEFUN(cfg_esme_alert_notif, cfg_esme_alert_notif_cmd,
+	"alert-notifications",
+	"Disable sending of SMPP Alert Notifications for this ESME")
+{
+	struct osmo_smpp_acl *acl = vty->index;
+
+	acl->alert_notifications = 1;
+
+	return CMD_SUCCESS;
+}
+
+DEFUN(cfg_esme_no_alert_notif, cfg_esme_no_alert_notif_cmd,
+	"no alert-notifications", NO_STR
+	"Disable sending of SMPP Alert Notifications for this ESME")
+{
+	struct osmo_smpp_acl *acl = vty->index;
+
+	acl->alert_notifications = 0;
+
+	return CMD_SUCCESS;
+}
+
 
 static void dump_one_esme(struct vty *vty, struct osmo_esme *esme)
 {
@@ -519,7 +541,7 @@ static void dump_one_esme(struct vty *vty, struct osmo_esme *esme)
 
 DEFUN(show_esme, show_esme_cmd,
 	"show smpp esme",
-	SHOW_STR "SMPP Interface\n" "SMPP Extrenal SMS Entity\n")
+	SHOW_STR "SMPP Interface\n" "SMPP External SMS Entity\n")
 {
 	struct smsc *smsc = smsc_from_vty(vty);
 	struct osmo_esme *esme;
@@ -560,6 +582,8 @@ static void config_write_esme_single(struct vty *vty, struct osmo_smpp_acl *acl)
 		vty_out(vty, "  osmocom-extensions%s", VTY_NEWLINE);
 	if (acl->dcs_transparent)
 		vty_out(vty, "  dcs-transparent%s", VTY_NEWLINE);
+	if (!acl->alert_notifications)
+		vty_out(vty, "  no alert-notifications%s", VTY_NEWLINE);
 
 	llist_for_each_entry(r, &acl->route_list, list)
 		write_esme_route_single(vty, r);
@@ -603,6 +627,8 @@ int smpp_vty_init(void)
 	install_element(SMPP_ESME_NODE, &cfg_esme_no_osmo_ext_cmd);
 	install_element(SMPP_ESME_NODE, &cfg_esme_dcs_transp_cmd);
 	install_element(SMPP_ESME_NODE, &cfg_esme_no_dcs_transp_cmd);
+	install_element(SMPP_ESME_NODE, &cfg_esme_alert_notif_cmd);
+	install_element(SMPP_ESME_NODE, &cfg_esme_no_alert_notif_cmd);
 
 	install_element_ve(&show_esme_cmd);
 
