@@ -61,7 +61,7 @@ static const char *config_file = "openbsc.cfg";
 static const char *rf_ctrl = NULL;
 extern const char *openbsc_copyright;
 static int daemonize = 0;
-static struct llist_head access_lists;
+static LLIST_HEAD(access_lists);
 
 struct llist_head *bsc_access_lists(void)
 {
@@ -81,6 +81,7 @@ static void print_help()
 	printf("  -d option --debug=DRLL:DCC:DMM:DRR:DRSL:DNM enable debugging\n");
 	printf("  -s --disable-color\n");
 	printf("  -T --timestamp. Print a timestamp in the debug output.\n");
+	printf("  -V --version. Print the version of OsmoBSC.\n");
 	printf("  -c --config-file filename The config file to use.\n");
 	printf("  -l --local=IP. The local address of the MGCP.\n");
 	printf("  -e --log-level number. Set a global loglevel.\n");
@@ -99,6 +100,7 @@ static void handle_options(int argc, char **argv)
 			{"config-file", 1, 0, 'c'},
 			{"disable-color", 0, 0, 's'},
 			{"timestamp", 0, 0, 'T'},
+			{"version", 0, 0, 'V' },
 			{"local", 1, 0, 'l'},
 			{"log-level", 1, 0, 'e'},
 			{"rf-ctl", 1, 0, 'r'},
@@ -106,7 +108,7 @@ static void handle_options(int argc, char **argv)
 			{0, 0, 0, 0}
 		};
 
-		c = getopt_long(argc, argv, "hd:DsTc:e:r:t",
+		c = getopt_long(argc, argv, "hd:DsTVc:e:r:t",
 				long_options, &option_index);
 		if (c == -1)
 			break;
@@ -131,6 +133,10 @@ static void handle_options(int argc, char **argv)
 		case 'T':
 			log_set_print_timestamp(osmo_stderr_target, 1);
 			break;
+		case 'V':
+			print_version(1);
+			exit(0);
+			break;
 		case 'e':
 			log_set_log_level(osmo_stderr_target, atoi(optarg));
 			break;
@@ -214,11 +220,9 @@ int main(int argc, char **argv)
 	vty_info.copyright = openbsc_copyright;
 	vty_init(&vty_info);
 	bsc_vty_init(bsc_gsmnet);
-	bsc_msg_lst_vty_init(tall_bsc_ctx, &access_lists, BSC_NODE);
+	bsc_msg_acc_lst_vty_init(tall_bsc_ctx, &access_lists, BSC_NODE);
 	ctrl_vty_init(tall_bsc_ctx);
 
-	INIT_LLIST_HEAD(&access_lists);
-
 	/* parse options */
 	handle_options(argc, argv);
 
