@@ -153,7 +153,7 @@ static int mgcp_create_port(struct bsc_msc_data *data)
 	}
 
 	osmo_wqueue_init(&data->mgcp_agent, 10);
-	data->mgcp_agent.bfd.when = BSC_FD_READ;
+	data->mgcp_agent.bfd.when = OSMO_FD_READ;
 	data->mgcp_agent.bfd.data = data;
 	data->mgcp_agent.read_cb = mgcp_do_read;
 	data->mgcp_agent.write_cb = mgcp_do_write;
@@ -224,18 +224,11 @@ static void handle_ctrl(struct bsc_msc_data *msc, struct msgb *msg)
 {
 	int ret;
 	struct ctrl_cmd *cmd;
+	bool parse_failed;
 
-	cmd = ctrl_cmd_parse(msc->msc_con, msg);
-	if (!cmd) {
+	cmd = ctrl_cmd_parse3(msc->msc_con, msg, &parse_failed);
+	if (cmd->type == CTRL_TYPE_ERROR && parse_failed) {
 		LOGP(DMSC, LOGL_ERROR, "Failed to parse control message.\n");
-		cmd = talloc_zero(msc->msc_con, struct ctrl_cmd);
-		if (!cmd) {
-			LOGP(DMSC, LOGL_ERROR, "OOM!\n");
-			return;
-		}
-		cmd->type = CTRL_TYPE_ERROR;
-		cmd->id = "err";
-		cmd->reply = "Failed to parse control message.";
 
 		ctrl_cmd_send(&msc->msc_con->write_queue, cmd);
 		talloc_free(cmd);
@@ -463,9 +456,7 @@ static int answer_challenge(struct bsc_msc_data *data, struct msgb *inp, struct
 		.algo		= OSMO_AUTH_ALG_MILENAGE,
 	};
 
-	ret = ipa_ccm_idtag_parse_off(&tvp,
-				inp->l2h + 1,
-				msgb_l2len(inp) - 1, 1);
+	ret = ipa_ccm_id_get_parse(&tvp, inp->l2h + 1, msgb_l2len(inp) - 1);
 	if (ret < 0) {
 		LOGP(DMSC, LOGL_ERROR, "ignoring IPA response "
 			"message with malformed TLVs: %s\n", osmo_hexdump(inp->l2h + 1,
