@@ -211,7 +211,7 @@ int bsc_mgcp_assign_patch(struct nat_sccp_connection *con, struct msgb *msg)
 	llist_for_each_entry(mcon, &con->bsc->nat->sccp_connections, list_entry) {
 		if (mcon->msc_endp == endp) {
 			LOGP(DNAT, LOGL_ERROR,
-			     "Endpoint %d was assigned to 0x%x and now 0x%x\n",
+			     "Endpoint 0x%x was assigned to 0x%x and now 0x%x\n",
 			     endp,
 			     sccp_src_ref_to_int(&mcon->patched_ref),
 			     sccp_src_ref_to_int(&con->patched_ref));
@@ -521,8 +521,8 @@ static int bsc_mgcp_policy_cb(struct mgcp_trunk_config *tcfg, int endpoint, int
 	mgcp_endp = &nat->mgcp_cfg->trunk.endpoints[endpoint];
 
 	if (bsc_endp->transaction_id) {
-		LOGP(DMGCP, LOGL_ERROR, "Endpoint 0x%x had pending transaction: '%s'\n",
-		     endpoint, bsc_endp->transaction_id);
+		LOGP(DMGCP, LOGL_ERROR, "Endpoint 0x%x had pending transaction: '%s' state %d\n",
+		     endpoint, bsc_endp->transaction_id, bsc_endp->transaction_state);
 		talloc_free(bsc_endp->transaction_id);
 		bsc_endp->transaction_id = NULL;
 		bsc_endp->transaction_state = 0;
@@ -663,19 +663,38 @@ static void free_chan_downstream(struct mgcp_endpoint *endp, struct bsc_endpoint
 	mgcp_release_endp(endp);
 }
 
+/*! Check MGCP parameter line (string) for plausibility.
+ *  \param[in] endp pointer to endpoint (only used for log output)
+ *  \param[in] line single parameter line from the MGCP message
+ *  \returns 1 when line seems plausible, 0 on error */
+static int bsc_mgcp_check_param(const struct mgcp_endpoint *endp, const char *line)
+{
+	const size_t line_len = strlen(line);
+	if (line[0] != '\0' && line_len < 2) {
+		LOGP(DLMGCP, LOGL_ERROR,
+		     "Wrong MGCP option format: '%s' on 0x%x\n",
+		     line, ENDPOINT_NUMBER(endp));
+		return 0;
+	}
+
+	/* FIXME: A couple more checks wouldn't hurt... */
+
+	return 1;
+}
+
 static void bsc_mgcp_osmux_confirm(struct mgcp_endpoint *endp, const char *str)
 {
 	unsigned int osmux_cid;
-	char *res;
+	const char x_osmux_prefix[] = "X-Osmux: ";
+	const size_t x_osmux_prefix_len = strlen(x_osmux_prefix);
 
-	res = strstr(str, "X-Osmux: ");
-	if (!res) {
+	if (!str || strncasecmp(str, x_osmux_prefix, x_osmux_prefix_len)) {
 		LOGP(DMGCP, LOGL_INFO,
-		     "BSC doesn't want to use Osmux, failing back to RTP\n");
+		     "BSC doesn't want to use Osmux, failing back to RTP (str=%s)\n", str);
 		goto err;
 	}
 
-	if (sscanf(res, "X-Osmux: %u", &osmux_cid) != 1) {
+	if (sscanf(str + x_osmux_prefix_len, "%u", &osmux_cid) != 1) {
 		LOGP(DMGCP, LOGL_ERROR, "Failed to parse Osmux CID '%s'\n",
 		     str);
 		goto err;
@@ -713,6 +732,10 @@ void bsc_mgcp_forward(struct bsc_connection *bsc, struct msgb *msg)
 	struct mgcp_endpoint *endp = NULL;
 	int i, code;
 	char transaction_id[60];
+	char *save;
+	char *line = NULL;
+	char *line_osmux = NULL;
+	char *line_ci = NULL;
 
 	/* Some assumption that our buffer is big enough.. and null terminate */
 	if (msgb_l2len(msg) > 2000) {
@@ -752,14 +775,42 @@ void bsc_mgcp_forward(struct bsc_connection *bsc, struct msgb *msg)
 		return;
 	}
 
-	endp->ci = bsc_mgcp_extract_ci((const char *) msg->l2h);
+	save = alloca(msgb_l2len(msg) + 1); /* +1 -> null char appended */
+	memcpy(save, msg->l2h, msgb_l2len(msg) + 1);
+	for_each_line(line, save) {
+
+		if (!bsc_mgcp_check_param(endp, line))
+			continue;
+
+		switch (line[0]) {
+		case 'I':
+		case 'i':
+			line_ci = line;
+			break;
+		case 'X':
+		case 'x':
+			if (strncasecmp(line, "X-Osmux: ", strlen("X-Osmux: ")) == 0)
+				line_osmux = line;
+			/* Ignore unknown X-headers */
+			break;
+		case '\0':
+			/* Reached SDP section, we are done parsing header */
+			goto mgcp_header_done;
+			break;
+		default:
+			break;
+		}
+	}
+mgcp_header_done:
+
+	endp->ci = bsc_mgcp_extract_ci((const char *) line_ci);
 	if (endp->ci == CI_UNUSED) {
 		free_chan_downstream(endp, bsc_endp, bsc);
 		return;
 	}
 
 	if (endp->osmux.state == OSMUX_STATE_NEGOTIATING)
-		bsc_mgcp_osmux_confirm(endp, (const char *) msg->l2h);
+		bsc_mgcp_osmux_confirm(endp, line_osmux);
 
 	/* If we require osmux and it is disabled.. fail */
 	if (nat_osmux_only(bsc->nat->mgcp_cfg, bsc->cfg) &&
@@ -806,17 +857,22 @@ int bsc_mgcp_parse_response(const char *str, int *code, char transaction[60])
 uint32_t bsc_mgcp_extract_ci(const char *str)
 {
 	unsigned int ci;
-	char *res = strstr(str, "I: ");
-	if (!res) {
-		LOGP(DMGCP, LOGL_ERROR, "No CI in msg '%s'\n", str);
+	const char ci_prefix[] = "I: ";
+	const size_t ci_prefix_len = strlen(ci_prefix);
+
+	if (!str || strncasecmp(str, ci_prefix, ci_prefix_len)) {
+		LOGP(DMGCP, LOGL_ERROR, "No CI in line '%s'\n", str);
 		return CI_UNUSED;
 	}
 
-	if (sscanf(res, "I: %u", &ci) != 1) {
-		LOGP(DMGCP, LOGL_ERROR, "Failed to parse CI in msg '%s'\n", str);
+	if (sscanf(str + ci_prefix_len, "%x", &ci) != 1) {
+		LOGP(DMGCP, LOGL_ERROR, "Failed to parse CI in line '%s'\n", str);
 		return CI_UNUSED;
 	}
 
+	if (ci == CI_UNUSED)
+		LOGP(DMGCP, LOGL_ERROR, "CI field '%s' parsed as reserved value CI_UNUSED\n", str);
+
 	return ci;
 }
 
@@ -939,7 +995,7 @@ copy:
 	 * safely append another line.
 	 */
 	if (ensure_mode_set && !found_fmtp && payload != -1) {
-		snprintf(buf, sizeof(buf) - 1, "a=fmtp:%d mode-set=2%s",
+		snprintf(buf, sizeof(buf) - 1, "a=fmtp:%d mode-set=2 octet-align=1%s",
 			payload, cr ? "\r\n" : "\n");
 		buf[sizeof(buf) - 1] = '\0';
 		output->l3h = msgb_put(output, strlen(buf));
@@ -1071,7 +1127,7 @@ static int init_mgcp_socket(struct bsc_nat *nat, struct mgcp_config *cfg)
 	}
 
 	osmo_wqueue_init(&cfg->gw_fd, 10);
-	cfg->gw_fd.bfd.when = BSC_FD_READ;
+	cfg->gw_fd.bfd.when = OSMO_FD_READ;
 	cfg->gw_fd.bfd.data = nat;
 	cfg->gw_fd.read_cb = mgcp_do_read;
 	cfg->gw_fd.write_cb = mgcp_do_write;
@@ -1111,7 +1167,6 @@ int bsc_mgcp_nat_init(struct bsc_nat *nat)
 	/* some more MGCP config handling */
 	cfg->data = nat;
 	cfg->policy_cb = bsc_mgcp_policy_cb;
-	cfg->trunk.force_realloc = 1;
 
 	if (cfg->bts_ip)
 		talloc_free(cfg->bts_ip);
