@@ -36,6 +36,7 @@
 #include <unistd.h>
 #include <string.h>
 #include <errno.h>
+#include <limits.h>
 
 
 #define NAT_MAX_CTRL_ID 65535
@@ -85,10 +86,20 @@ void bsc_nat_ctrl_del_pending(struct bsc_cmd_list *pending)
 static struct bsc_cmd_list *bsc_get_pending(struct bsc_connection *bsc, char *id_str)
 {
 	struct bsc_cmd_list *cmd_entry;
-	int id = atoi(id_str);
-	if (id == 0)
+	char * endptr = NULL;
+	long int long_id;
+	int id;
+
+	errno = 0;
+	long_id = (int) strtol(id_str, &endptr, 10);
+	 /* check parse errors */
+	if (id_str[0] == '\0' || endptr[0] != '\0')
+		return NULL;
+	/* check value store errors */
+	if (errno == ERANGE || long_id > INT_MAX || long_id < 0)
 		return NULL;
 
+	id = (int) long_id;
 	llist_for_each_entry(cmd_entry, &bsc->cmd_pending, list_entry) {
 		if (cmd_entry->nat_id == id) {
 			return cmd_entry;
@@ -100,23 +111,15 @@ static struct bsc_cmd_list *bsc_get_pending(struct bsc_connection *bsc, char *id
 int bsc_nat_handle_ctrlif_msg(struct bsc_connection *bsc, struct msgb *msg)
 {
 	struct ctrl_cmd *cmd;
+	bool parse_failed;
 	struct bsc_cmd_list *pending;
 	char *var;
 
-	cmd = ctrl_cmd_parse(bsc, msg);
+	cmd = ctrl_cmd_parse3(bsc, msg, &parse_failed);
 	msgb_free(msg);
 
-	if (!cmd) {
-		cmd = talloc_zero(bsc, struct ctrl_cmd);
-		if (!cmd) {
-			LOGP(DNAT, LOGL_ERROR, "OOM!\n");
-			return -ENOMEM;
-		}
-		cmd->type = CTRL_TYPE_ERROR;
-		cmd->id = "err";
-		cmd->reply = "Failed to parse command.";
+	if (cmd->type == CTRL_TYPE_ERROR && parse_failed)
 		goto err;
-	}
 
 	if (bsc->cfg && !llist_empty(&bsc->cfg->lac_list)) {
 		if (cmd->variable) {
@@ -150,11 +153,14 @@ int bsc_nat_handle_ctrlif_msg(struct bsc_connection *bsc, struct msgb *msg)
 			ctrl_cmd_send(&pending->cmd->ccon->write_queue, cmd);
 			bsc_nat_ctrl_del_pending(pending);
 		} else {
-			/* We need to handle TRAPS here */
-			if ((cmd->type != CTRL_TYPE_ERROR) &&
-			    (cmd->type != CTRL_TYPE_TRAP)) {
-				LOGP(DNAT, LOGL_NOTICE, "Got control message "
-					"from BSC without pending entry\n");
+			if ((cmd->type == CTRL_TYPE_ERROR)) {
+				LOGP(DNAT, LOGL_NOTICE, "Got ERROR CTRL message "
+				     "from BSC without pending/valid ID %s: %s\n",
+				     cmd->id, cmd->reply);
+			} else {
+				LOGP(DNAT, LOGL_NOTICE, "Got %s CTRL message "
+				     "from BSC without pending entry\n",
+				     get_value_string(ctrl_type_vals, cmd->type));
 				cmd->type = CTRL_TYPE_ERROR;
 				cmd->reply = "No request outstanding";
 				goto err;
