@@ -436,7 +436,7 @@ static int last_endpoint = -1;
 static int mgcp_test_policy_cb(struct mgcp_trunk_config *cfg, int endpoint,
 			       int state, const char *transactio_id)
 {
-	fprintf(stderr, "Policy CB got state %d on endpoint %d\n",
+	fprintf(stderr, "Policy CB got state %d on endpoint 0x%x\n",
 		state, endpoint);
 	last_endpoint = endpoint;
 	return MGCP_POLICY_CONT;
@@ -543,7 +543,8 @@ static void test_messages(void)
 			if (msg)
 				printf("%s failed '%s'\n", t->name, (char *) msg->data);
 		} else if (strcmp((char *) msg->data, t->exp_resp) != 0)
-			printf("%s failed '%s'\n", t->name, (char *) msg->data);
+			printf("%s failed.\nExpected:\n%s\nGot:\n%s\n",
+			       t->name, t->exp_resp, (char *) msg->data);
 		msgb_free(msg);
 
 		if (dummy_packets)
@@ -602,7 +603,7 @@ static void test_messages(void)
 			OSMO_ASSERT(last_endpoint != -1);
 			endp = &cfg->trunk.endpoints[last_endpoint];
 
-			fprintf(stderr, "endpoint %d: "
+			fprintf(stderr, "endpoint 0x%x: "
 				"payload type BTS %d (exp %d), NET %d (exp %d)\n",
 				last_endpoint,
 				endp->bts_end.codec.payload_type, t->exp_bts_ptype,
@@ -653,7 +654,8 @@ static void test_retransmission(void)
 		msg = mgcp_handle_message(cfg, inp);
 		msgb_free(inp);
 		if (strcmp((char *) msg->data, t->exp_resp) != 0)
-			printf("%s failed '%s'\n", t->name, (char *) msg->data);
+			printf("%s failed.\nExpected:\n%s\nGot:\n%s\n",
+			       t->name, t->exp_resp, (char *) msg->data);
 		msgb_free(msg);
 
 		/* Retransmit... */
@@ -662,7 +664,8 @@ static void test_retransmission(void)
 		msg = mgcp_handle_message(cfg, inp);
 		msgb_free(inp);
 		if (strcmp((char *) msg->data, t->exp_resp) != 0)
-			printf("%s failed '%s'\n", t->name, (char *) msg->data);
+			printf("%s failed.\nExpected:\n%s\nGot:\n%s\n",
+			       t->name, t->exp_resp, (char *) msg->data);
 		msgb_free(msg);
 	}
 
@@ -1205,7 +1208,7 @@ static void test_osmux_cid(void)
 
 int main(int argc, char **argv)
 {
-	msgb_talloc_ctx_init(NULL, 0);
+	void *msgb_ctx = msgb_talloc_ctx_init(NULL, 0);
 	osmo_init_logging(&log_info);
 
 	test_strline();
@@ -1224,6 +1227,9 @@ int main(int argc, char **argv)
 	test_no_name();
 	test_osmux_cid();
 
+	OSMO_ASSERT(talloc_total_size(msgb_ctx) == 0);
+	OSMO_ASSERT(talloc_total_blocks(msgb_ctx) == 1);
+	talloc_free(msgb_ctx);
 	printf("Done\n");
 	return EXIT_SUCCESS;
 }
